@@ -282,8 +282,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     "If you are certain you know what you are doing, click"
                     " Yes."
                 ),
-                QtWidgets.QMessageBox.StandardButton.Yes |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Yes
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
                 QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
@@ -539,6 +539,13 @@ class CalibrationWindow(QtWidgets.QWidget):
             )
             return
 
+        if not self.app.calibration.isValid1Port():
+            self.app.showError(
+                "Not enough data to apply calibration."
+                " Please complete SOL calibration and try again."
+            )
+            return
+
         cal_element.short_is_ideal = True
         cal_element.open_is_ideal = True
         cal_element.load_is_ideal = True
@@ -633,18 +640,19 @@ class CalibrationWindow(QtWidgets.QWidget):
                     self.app.sweepSource,
                 )
                 self.app.worker.signals.updated.emit()
+
         except ValueError as e:
-            if logger.isEnabledFor(logging.DEBUG):
-                raise
             # showError here hides the calibration window,
             # so we need to pop up our own
-            QtWidgets.QMessageBox.warning(
-                self, "Error applying calibration", str(e)
-            )
             self.calibration_status_label.setText(
                 "Applying calibration failed."
             )
             self.calibration_source_label.setText(self.app.calibration.source)
+            self.app.showError(
+                f"{e}" " Please complete SOL calibration and try again."
+            )
+            self.reset()
+            return
 
     def loadCalibration(self):
         filename, _ = QtWidgets.QFileDialog.getOpenFileName(
@@ -724,7 +732,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                 " in save slot 0 before starting.</b><br><br>"
                 "Once you are ready to proceed, press Ok."
             ),
-            QtWidgets.QMessageBox.StandardButton.Ok | QtWidgets.QMessageBox.StandardButton.Cancel,
+            QtWidgets.QMessageBox.StandardButton.Ok
+            | QtWidgets.QMessageBox.StandardButton.Cancel,
         )
         response = introduction.exec()
         if response != QtWidgets.QMessageBox.StandardButton.Ok:
@@ -763,7 +772,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                 " NanoVNA.\n\n"
                 "Press Ok when you are ready to continue."
             ),
-            QtWidgets.QMessageBox.StandardButton.Ok | QtWidgets.QMessageBox.StandardButton.Cancel,
+            QtWidgets.QMessageBox.StandardButton.Ok
+            | QtWidgets.QMessageBox.StandardButton.Cancel,
         )
 
         response = short_step.exec()
@@ -799,8 +809,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     " cable unconnected if desired.\n\n"
                     "Press Ok when you are ready to continue."
                 ),
-                QtWidgets.QMessageBox.StandardButton.Ok |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Ok
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
             response = open_step.exec()
@@ -826,8 +836,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     " NanoVNA.\n\n"
                     "Press Ok when you are ready to continue."
                 ),
-                QtWidgets.QMessageBox.StandardButton.Ok |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Ok
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
             response = load_step.exec()
@@ -887,8 +897,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     " port 0.\n\n"
                     "Press Ok when you are ready to continue."
                 ),
-                QtWidgets.QMessageBox.StandardButton.Ok |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Ok
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
             response = isolation_step.exec()
@@ -914,8 +924,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     " port 0 and port 1 of the NanoVNA.\n\n"
                     "Press Ok when you are ready to continue."
                 ),
-                QtWidgets.QMessageBox.StandardButton.Ok |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Ok
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
             response = through_step.exec()
@@ -940,8 +950,8 @@ class CalibrationWindow(QtWidgets.QWidget):
                     "The calibration process is now complete. Press"
                     ' "Apply" to apply the calibration parameters.'
                 ),
-                QtWidgets.QMessageBox.StandardButton.Apply |
-                QtWidgets.QMessageBox.StandardButton.Cancel,
+                QtWidgets.QMessageBox.StandardButton.Apply
+                | QtWidgets.QMessageBox.StandardButton.Cancel,
             )
 
             response = apply_step.exec()
